# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2024-01-25)

### Feature

* Add --fmt to output as JSON or YAML for most relevant cases ([`2ce4c17`](https://github.com/educationwarehouse/edwh-uptime-plugin/commit/2ce4c17ed4cdc6fb465ac50eeeedefa83b18458b))
* Started on pytest but free tier api is limited to 10 req/min ([`1a1099a`](https://github.com/educationwarehouse/edwh-uptime-plugin/commit/1a1099a2954229ea2a1bed7e25fd342c2149da44))
* Add edit and reset monitor; added docstrings ([`3a21c27`](https://github.com/educationwarehouse/edwh-uptime-plugin/commit/3a21c270f8ddfce8218abc6a6b19808f2be99ce7))
* Initial version with some endpoints implemented ([`856b589`](https://github.com/educationwarehouse/edwh-uptime-plugin/commit/856b5891fde5e773c986f43d34abbb38fe87d2ef))

### Documentation

* Added more basic info ([`f9c0089`](https://github.com/educationwarehouse/edwh-uptime-plugin/commit/f9c008935f736daec63627dc94088c393c99bd88))